# Bam

[![PyPI version](https://badge.fury.io/py/bam.svg)](https://badge.fury.io/py/bam)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

Bam is a lightweight and easy-to-use command-line interface (CLI) tool for creating and running AI agent containers. It is currently Docker-based.

## Installation

You can install Bam using pip:

```bash
pip install bambot
```
## Getting Started

To get started with bambot, follow these simple steps:

1. Install bambot using pip:
```bash
pip install bambot
```
2. Initialize a new Bam project:
```bash
bam init [CONTAINER_NAME]
```
3. Build the Bam project locally:
```bash
cd [CONTAINER_NAME]
bam build
```
4. Start the AI agent container locally:
```bash
bam start
```

That's it! You're now ready to start using Bam to create and run AI agent containers.

## Documentation

For detailed documentation and additional features, please visit our website at [bam.bot](https://bam.bot) (coming soon).

## License

bambot is released under the [MIT License](LICENSE).

## Support

If you have any questions, issues, or suggestions, please [open an issue](https://github.com/Bam-Corp/bambot/issues) on our GitHub repository or email spencer@bam.bot.

Happy coding!

*Note: Bam is VERY much a work-in-progress. more to come very soon!*